@@ -32,10 +32,17 @@ char **l_strsplit(const char *str, const char sep);
 char **l_strsplit_set(const char *str, const char *separators);
 char *l_strjoinv(char **str_array, const char delim);
 
+char **l_strv_new(void);
 void l_strv_free(char **str_array);
 unsigned int l_strv_length(char **str_array);
 bool l_strv_contains(char **str_array, const char *item);
 char **l_strv_append(char **str_array, const char *str);
+char **l_strv_append_printf(char **str_array, const char *format, ...)
+					__attribute__((format(printf, 2, 3)));
+char **l_strv_append_vprintf(char **str_array, const char *format,
+							va_list args)
+					__attribute__((format(printf, 2, 0)));
+char **l_strv_copy(char **str_array);
 
 #ifdef __cplusplus
 }
